@@ -11,6 +11,7 @@ import inspect
 
 
 from .globaling import *
+from .odicting import odict
 from . import aiding
 from . import excepting
 from . import registering
@@ -22,34 +23,11 @@ from . import framing
 from .consoling import getConsole
 console = getConsole()
 
-
-#Class definitions should be singletons or borgs
-#instance should be only one should use singleton or borg
-
-def CreateInstances(store):
-    """Create action gloal lists and instances
-       must be function so can recreate after clear registry
-       globals good for module self tests
-    """
-    #special needs
-    needDone = DoneNeed(name = 'needDone', store = store)
-    needAlways = AlwaysNeed(name = 'needAlways', store = store)
-    needStatus = StatusNeed(name = 'needStatus', store = store)
-    needUpdate = UpdateNeed(name = 'needUpdate', store = store)
-    needChange = ChangeNeed(name = 'needChange', store = store)
-
-    #dynamic need types
-    needBoolean = BooleanNeed(name = 'needBoolean', store = store)
-    needDirect = DirectNeed(name = 'needDirect', store = store)
-    needIndirect = IndirectNeed(name = 'needIndirect', store = store)
-
-
 class Need(acting.Actor):
     """Need Class for conditions  such as entry or trans
 
     """
-    Counter = 0  
-    Names = {}
+    Registry = odict()
 
     def expose(self):
         """
@@ -127,6 +105,25 @@ class DoneNeed(Need):
 
         return result
     
+    def resolve(self, tasker, **kwa):
+        """Resolves value (tasker) link that is passed in as tasker parm
+           resolved link is passed back to container act to update in act's parms
+        """
+        parms = super(DoneNeed, self).resolve( **kwa) 
+
+        if not isinstance(tasker, tasking.Tasker): # name of tasker so resolve
+            if tasker not in tasking.Tasker.Names: 
+                raise excepting.ResolveError("ResolveError: Bad need done aux link", tasker, self.name)
+            tasker = tasking.Tasker.Names[tasker] #replace tasker name with tasker
+
+        #if not tasker.schedule in [AUX, SLAVE]: 
+            #raise excepting.ResolveError("ResolveError: Bad need done tasker not auxiliary or slave", tasker, self.name)
+
+        parms['tasker'] = tasker #replace name with valid link
+
+        return parms #return items are updated in original act parms
+    
+    
     def cloneParms(self, parms, clones, **kw):
         """ Returns parms fixed up for framing cloning. This includes:
             Reverting any Frame links to name strings,
@@ -152,24 +149,6 @@ class DoneNeed(Need):
         
         return parms        
 
-    def resolveLinks(self, tasker, **kw):
-        """Resolves value (tasker) link that is passed in as tasker parm
-           resolved link is passed back to container act to update in act's parms
-        """
-        parms = {}
-
-        if not isinstance(tasker, tasking.Tasker): # name of tasker so resolve
-            if tasker not in tasking.Tasker.Names: 
-                raise excepting.ResolveError("ResolveError: Bad need done aux link", tasker, self.name)
-            tasker = tasking.Tasker.Names[tasker] #replace tasker name with tasker
-
-        #if not tasker.schedule in [AUX, SLAVE]: 
-            #raise excepting.ResolveError("ResolveError: Bad need done tasker not auxiliary or slave", tasker, self.name)
-
-        parms['tasker'] = tasker #replace name with valid link
-
-        return parms #return items are updated in original act parms
-
 class StatusNeed(Need):
     """StatusNeed Need
 
@@ -191,6 +170,22 @@ class StatusNeed(Need):
 
         return result
     
+    def resolve(self, tasker, **kwa):
+        """Resolves value (tasker) link that is passed in as parm
+           resolved link is passed back to container act to update in act's parms
+        """
+        parms = super(StatusNeed, self).resolve( **kwa) 
+
+        if not isinstance(tasker, tasking.Tasker): #so name of tasker
+            if tasker not in tasking.Tasker.Names: 
+                raise excepting.ResolveError("ResolveError: Bad need done tasker link", tasker, self.name)
+            tasker = tasking.Tasker.Names[tasker] #replace tasker name with tasker
+
+        parms['tasker'] = tasker #replace name with valid link
+
+        return parms #return items are updated in original act parms
+    
+    
     def cloneParms(self, parms, clones, **kw):
         """ Returns parms fixed up for framing cloning. This includes:
             Reverting any Frame links to name strings,
@@ -216,21 +211,6 @@ class StatusNeed(Need):
         
         return parms    
 
-    def resolveLinks(self, tasker, status, **kw):
-        """Resolves value (tasker) link that is passed in as parm
-           resolved link is passed back to container act to update in act's parms
-        """
-        parms = dict(status=status)
-
-        if not isinstance(tasker, tasking.Tasker): #so name of tasker
-            if tasker not in tasking.Tasker.Names: 
-                raise excepting.ResolveError("ResolveError: Bad need done tasker link", tasker, self.name)
-            tasker = tasking.Tasker.Names[tasker] #replace tasker name with tasker
-
-        parms['tasker'] = tasker #replace name with valid link
-
-        return parms #return items are updated in original act parms
-
 class BooleanNeed(Need):
     """BooleanNeed Need
 
@@ -306,12 +286,57 @@ class MarkerNeed(Need):
             .name = unique name for action instance
             .store = shared data store
         parms:
-            share
-            name
+            share       share ref holding mark
+            name        name of frame where marker is watching
             frame       only used in resolvelinks
             marker      only used in resolvelinks
     
     """
+    def resolve(self, share, frame, marker, **kwa):
+        """ Resolves frame name link and then
+           inserts marker as first enact in the resolved frame
+           
+        """
+        parms = super(MarkerNeed, self).resolve( **kwa) 
+        
+        if not isinstance(frame, framing.Frame): # must be pathname
+            if frame not in framing.Frame.Names:
+                msg = "ResolveError: Bad need update frame link"
+                raise excepting.ResolveError(msg, frame, self.name)
+            parms['frame'] = frame = framing.Frame.Names[frame] #replace frame name with frame
+        
+        if not share.marks.get(frame.name):
+            share.marks[frame.name] = storing.Mark()
+            
+        found = False
+        for enact in frame.enacts:
+            if (isinstance(enact.actor, acting.Actor) and 
+                    enact.actor.name is marker and
+                    enact.parms['share'] is share and
+                    enact.parms['name'] == frame.name):
+                found = True
+                break
+            
+        if not found:
+            if marker not in acting.Actor.Registry:
+                msg = "ResolveError: Bad need marker link"
+                raise excepting.ResolveError(msg, marker, self.name)
+            
+            markerParms = dict(share=share, frame=frame.name)
+            parms['marker'] = marker = acting.Act(  actor=marker,
+                                                    registrar=acting.Actor,
+                                                    parms=markerParms)
+            
+            frame.insertEnact(marker)
+            console.profuse("     Added {0} {1} with {2} in {3}\n".format(
+                'enact',
+                marker,
+                marker.parms['share'].name,
+                marker.parms['frame']))
+            marker.resolve()
+                
+        return parms #return items are updated in original act parms    
+    
     def cloneParms(self, parms, clones, **kw):
         """ Returns parms fixed up for framing cloning. This includes:
             Reverting any Frame links to name strings,
@@ -334,50 +359,6 @@ class MarkerNeed(Need):
 
         return parms    
     
-    def resolveLinks(self, share, name, frame, marker, **kw):
-        """Resolves frame framename link and then
-           inserts marker as first enact in the resolved frame
-           
-           If appropriate resolved link(s) are passed back to container act to
-           update the act's parms
-        """
-        parms = dict()
-        
-        if not share.marks.get(name):
-            share.marks[name] = storing.Mark()        
-    
-        if not isinstance(frame, framing.Frame): # must be pathname
-            if frame not in framing.Frame.Names: 
-                raise excepting.ResolveError("ResolveError: Bad need update frame link", frame, self.name)
-            parms['frame'] = frame = framing.Frame.Names[frame] #replace frame name with frame
-        
-        if not isinstance(marker, acting.Marker): #marker is name of actor
-            if marker not in acting.Actor.Names:
-                raise excepting.ResolveError("ResolveError: Bad need marker link", marker, self.name)
-            parms['marker'] = marker = acting.Actor.Names[marker]
-        
-        
-        found = False
-        for enact in frame.enacts:
-            if (enact.actor is marker and
-                    enact.parms['share'] is share and
-                    enact.parms['name'] == name):
-                found = True
-                break
-            
-        if not found:
-            markerParms = dict(share=share, name=name)
-            markerAct = acting.Act(marker, parms=markerParms)
-            
-            frame.insertEnact(markerAct)
-            console.profuse("     Added {0} {1} with {2} in {3}\n".format(
-                'enact',
-                markerAct.actor.name,
-                markerAct.parms['share'].name,
-                markerAct.parms['name']))   
-                
-        return parms #return items are updated in original act parms
-    
 class UpdateNeed(MarkerNeed):
     """ UpdateNeed Need
 
@@ -386,22 +367,21 @@ class UpdateNeed(MarkerNeed):
             .store = shared data store
 
         parameters:
-            share
-            name
-            frame       only used in resolvelinks
-            marker      only used in resolvelinks
+            share = resolved share that is marked
+            frame = resolved frame where marker is placed
+            marker = marker kind name
     """
-    def action(self, share, name, **kw):
+    def action(self, share, frame, **kw):
         """ Check if share updated while in frame/mark denoted by name key if any
             Default is False
         """
         result = False
-        mark = share.marks.get(name) #get mark from mark frame name key
+        mark = share.marks.get(frame.name) #get mark from mark frame name key
         if mark and mark.stamp != None:
             result = share.stamp >= mark.stamp #equals so catch updates on enter
         
         console.profuse("Need Share {0} update in Frame {1} = {2}\n".format(
-            share.name, name, result)) 
+            share.name, frame.name, result)) 
 
         return result
 
@@ -417,12 +397,12 @@ class ChangeNeed(MarkerNeed):
             frame       only used in resolvelinks
             marker      only used in resolvelinks
     """
-    def action(self, share, name, **kw):
+    def action(self, share, frame, **kw):
         """ Check if share data changed while in frame/mark denoted by name key if any
             Default is False
         """
         result = False
-        mark = share.marks.get(name) #get mark from mark frame name key
+        mark = share.marks.get(frame.name) #get mark from mark frame name key
         if mark and mark.data != None:
             for field, value in share.items():
                 try:
@@ -437,7 +417,7 @@ class ChangeNeed(MarkerNeed):
                          
         
         console.profuse("Need Share {0} change in Frame {1} = {2}\n".format(
-            share.name, name, result)) 
+            share.name, frame.name, result)) 
 
         return result
 
