@@ -5,10 +5,6 @@
 
 __all__ = ['interior', 'exterior'] 
 
-
 for m in __all__:
     exec "from . import %s" % m  #relative import
     #print "Imported %s" % globals().get(m,'')
-
-#used by CreateAllInstances               
-_InstanceModules = [interior, exterior]
